@@ -1,15 +1,6 @@
 //! Validators for mint wrapper accounts.
 
-use anchor_lang::prelude::*;
-use vipers::prelude::*;
-
-use crate::AcceptAdmin;
-use crate::MinterUpdate;
-use crate::NewMinter;
-use crate::NewWrapper;
-use crate::OnlyAdmin;
-use crate::PerformMint;
-use crate::TransferAdmin;
+use crate::*;
 
 /// --------------------------------
 /// Instruction account structs
@@ -17,16 +8,8 @@ use crate::TransferAdmin;
 
 impl<'info> Validate<'info> for NewWrapper<'info> {
     fn validate(&self) -> Result<()> {
-        assert_keys_eq!(
-            self.token_mint.mint_authority.unwrap(),
-            self.mint_wrapper,
-            "mint authority"
-        );
-        assert_keys_eq!(
-            self.token_mint.freeze_authority.unwrap(),
-            self.mint_wrapper,
-            "freeze authority"
-        );
+        assert_keys_eq!(self.token_mint.mint_authority.unwrap(), self.mint_wrapper);
+        assert_keys_eq!(self.token_mint.freeze_authority.unwrap(), self.mint_wrapper);
         Ok(())
     }
 }
@@ -41,11 +24,7 @@ impl<'info> Validate<'info> for NewMinter<'info> {
 impl<'info> Validate<'info> for MinterUpdate<'info> {
     fn validate(&self) -> Result<()> {
         self.auth.validate()?;
-        assert_keys_eq!(
-            self.minter.mint_wrapper,
-            self.auth.mint_wrapper,
-            "mint_wrapper"
-        );
+        assert_keys_eq!(self.minter.mint_wrapper, self.auth.mint_wrapper);
         Ok(())
     }
 }
@@ -53,8 +32,8 @@ impl<'info> Validate<'info> for MinterUpdate<'info> {
 impl<'info> Validate<'info> for TransferAdmin<'info> {
     fn validate(&self) -> Result<()> {
         invariant!(self.admin.is_signer, Unauthorized);
-        assert_keys_eq!(self.admin, self.mint_wrapper.admin, "admin");
-        assert_keys_neq!(self.next_admin, self.mint_wrapper.admin, "next_admin");
+        assert_keys_eq!(self.admin, self.mint_wrapper.admin);
+        assert_keys_neq!(self.next_admin, self.mint_wrapper.admin);
 
         Ok(())
     }
@@ -63,11 +42,7 @@ impl<'info> Validate<'info> for TransferAdmin<'info> {
 impl<'info> Validate<'info> for AcceptAdmin<'info> {
     fn validate(&self) -> Result<()> {
         invariant!(self.pending_admin.is_signer, Unauthorized);
-        assert_keys_eq!(
-            self.pending_admin,
-            self.mint_wrapper.pending_admin,
-            "pending admin"
-        );
+        assert_keys_eq!(self.pending_admin, self.mint_wrapper.pending_admin);
         Ok(())
     }
 }
@@ -82,14 +57,14 @@ impl<'info> Validate<'info> for PerformMint<'info> {
 
         invariant!(self.minter_authority.is_signer, Unauthorized);
         invariant!(self.minter.allowance > 0, MinterAllowanceExceeded);
-        assert_keys_eq!(self.minter.mint_wrapper, self.mint_wrapper, "mint wrapper");
+        assert_keys_eq!(self.minter.mint_wrapper, self.mint_wrapper);
         assert_keys_eq!(
             self.minter_authority,
             self.minter.minter_authority,
-            "minter"
+            Unauthorized
         );
-        assert_keys_eq!(self.token_mint, self.mint_wrapper.token_mint, "token mint");
-        assert_keys_eq!(self.destination.mint, self.token_mint, "dest token mint");
+        assert_keys_eq!(self.token_mint, self.mint_wrapper.token_mint);
+        assert_keys_eq!(self.destination.mint, self.token_mint);
         Ok(())
     }
 }
@@ -101,7 +76,7 @@ impl<'info> Validate<'info> for PerformMint<'info> {
 impl<'info> Validate<'info> for OnlyAdmin<'info> {
     fn validate(&self) -> Result<()> {
         invariant!(self.admin.is_signer, Unauthorized);
-        assert_keys_eq!(self.admin, self.mint_wrapper.admin, "admin");
+        assert_keys_eq!(self.admin, self.mint_wrapper.admin);
         Ok(())
     }
 }
